@@ -2,13 +2,15 @@
 
 from orbitkit import util
 from orbitkit.file_extractor.dispatcher import FileDispatcher
+from orbitkit import id_srv
 
 name = 'orbitkit'
 
-__version__ = '0.0.9'
+__version__ = '0.1.1'
 VERSION = __version__
 
 __all__ = [
     'util',
     'FileDispatcher',
+    'id_srv',
 ]
